==> nextcloud-14.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/serverinfo/l10n/cs.js <==
OC.L10N.register(
    "serverinfo",
    {
    "Load average" : "Průměrné vytížení",
    "Last minute" : "Poslední minuta",
    "Memory info not available" : "Informace o paměti není dostupná",
    "Total" : "Celkem",
    "Current usage" : "Aktuální využití",
    "Users" : "Uživatelé",
    "Groups" : "Skupiny",
    "Links" : "Odkazy",
    "Federated sent" : "Sdruženě odesláno",
    "Federated received" : "Sdruženě přijato",
    "Last 24 hours" : "Posledních 24 hodin",
    "Last 1 hour" : "Poslední 1 hodina",
    "Last 5 mins" : "Uplynulých 5 minut",
    "Copy" : "Zkopírovat",
    "Copied!" : "Zkopírováno!",
    "Not supported!" : "Nepodporováno!",
    "Press Ctrl-C to copy." : "Zkopírujte stisknutím Ctrl+C.",
    "Monitoring" : "Sledování",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Poskytuje užitečné informace o serveru, jako vytížení procesoru, obsazenost operační paměti, obsazenost datového úložiště, počet uživatelů, atd.",
    "CPU load" : "Vytížení procesoru",
    "Memory usage" : "Využití paměti",
    "Active users" : "Aktivní uživatelé",
    "Shares" : "Sdílení",
    "Storage" : "Úložiště",
    "Users:" : "Uživatelé:",
    "Files:" : "Soubory:",
    "Version:" : "Verze:",
    "PHP" : "PHP",
    "Memory Limit:" : "Limit paměti:",
    "Max Execution Time:" : "Největší čas vykonávání:",
    "Upload max size:" : "Maximální velikost nahraného souboru:",
    "Database" : "Databáze",
    "Type:" : "Typ:",
    "Size:" : "Velikost:",
    "External monitoring tool" : "Externí nástroj pro sledování",
    "You can connect an external monitoring tool by using this end point: " : "Externí sledovací nástroj můžete připojit pomocí následujícího přípojného bodu: "
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");

==> nextcloud-14.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/serverinfo/l10n/cs.js <==
OC.L10N.register(
    "serverinfo",
    {
    "Load average" : "Průměrné vytížení",
    "Last minute" : "Poslední minuta",
    "Memory info not available" : "Informace o paměti není dostupná",
    "Total" : "Celkem",
    "Current usage" : "Aktuální využití",
    "Users" : "Uživatelé",
    "Groups" : "Skupiny",
    "Links" : "Odkazy",
    "Federated sent" : "Sdruženě odesláno",
    "Federated received" : "Sdruženě přijato",
    "Last 24 hours" : "Posledních 24 hodin",
    "Last 1 hour" : "Poslední 1 hodina",
    "Last 5 mins" : "Uplynulých 5 minut",
    "Copy" : "Zkopírovat",
    "Copied!" : "Zkopírováno!",
    "Not supported!" : "Nepodporováno!",
    "Press ⌘-C to copy." : "Zkopírujtete stisknutím ⌘-C.",
    "Press Ctrl-C to copy." : "Zkopírujte stisknutím Ctrl+C.",
    "Monitoring" : "Sledování",
    "Monitoring app with useful server information" : "Dohledovací aplikace s užitečnými informacemi o serveru",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Poskytuje užitečné informace o serveru, jako vytížení procesoru, obsazenost operační paměti, obsazenost datového úložiště, počet uživatelů, atd.",
    "CPU load" : "Vytížení procesoru",
    "Memory usage" : "Využití paměti",
    "Active users" : "Aktivní uživatelé",
    "Shares" : "Sdílení",
    "Storage" : "Úložiště",
    "Users:" : "Uživatelé:",
    "Files:" : "Soubory:",
    "Storages:" : "Úložiště:",
    "Free Space:" : "Volné místo:",
    "Nextcloud" : "Nextcloud",
    "Version:" : "Verze:",
    "Apps installed:" : "Nainstalované aplikace:",
    "Apps updates available:" : "Jsou k dispozici aktualizace aplikací:",
    "PHP" : "PHP",
    "Memory Limit:" : "Limit paměti:",
    "Max Execution Time:" : "Nejdelší umožněný čas vykonávání:",
    "Upload max size:" : "Maximální velikost nahraného souboru:",
    "Database" : "Databáze",
    "Type:" : "Typ:",
    "Size:" : "Velikost:",
    "External monitoring tool" : "Externí nástroj pro sledování",
    "You can connect an external monitoring tool by using this end point:" : "Externí dohledovací nástroj je možné napojit pomocí tohoto koncového bodu:",
    "You can connect an external monitoring tool by using this end point: " : "Externí sledovací nástroj můžete připojit pomocí následujícího přípojného bodu: "
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
